@@ -1,6 +1,7 @@
 """Helper script for usefull functions"""
 
 import json
+from multiprocessing import Process
 import os
 import shutil
 import sys
@@ -86,6 +87,16 @@ def get_file(file_name: str) -> str:
     return file_path
 
 
+def find_files_in_dir(dir_path: str, file_name: str) -> list[str]:
+    """Find all files in a directory with a certain name"""
+
+    files: list[str] = []
+    for file in os.listdir(dir_path):
+        if file_name in file:
+            files.append(file)
+    return files
+
+
 def get_local_files_path() -> str:
     """Get the local files path"""
 
@@ -402,7 +413,7 @@ def colored_text(
     color_base = colored.fg(base)  # type: ignore
     color_reset = colored.fg(WHITE)  # type: ignore
 
-    text_split = text.split(split_char)
+    text_split: list[str] = split_text(text, split_char)
     for i, text_section in enumerate(text_split):
         if i % 2:
             print(f"{color_new}{text_section}{color_base}", end="")
@@ -411,6 +422,30 @@ def colored_text(
     print(color_reset, end=end)
 
 
+def split_text(text: str, split_char: str = "&") -> list[str]:
+    """Split text on split_char, allowing for escaped split chars"""
+
+    text_split: list[str] = []
+    current_string = ""
+    skip = 0
+    for i, char in enumerate(text):
+        if skip > 0:
+            skip -= 1
+            continue
+        if char == "\\":
+            if text[i + 1] == split_char:
+                current_string += split_char
+                skip = 1
+                continue
+        if char == split_char:
+            text_split.append(current_string)
+            current_string = ""
+        else:
+            current_string += char
+    text_split.append(current_string)
+    return text_split
+
+
 def colored_list(
     items: list[str],
     extra_data: Any = None,
@@ -461,12 +496,56 @@ def write_save_data(save_data: bytes, country_code: str, path: str, prompt: bool
     return save_data
 
 
-def setup_tk():
-    """Setup tkinter"""
+def select_dir(title: str, default_dir: str) -> str:
+    """
+    Select a directory from the user
 
+    Args:
+        title (str): Title of the dialog
+        default_dir (str): Default directory to select
+
+    Returns:
+        str: Selected directory
+    """
+    root = setup_tk()
+    dir_path = filedialog.askdirectory(title=title, initialdir=default_dir, parent=root)
+    return dir_path
+
+
+def setup_tk() -> Tk:
+    """
+    Setup the tkinter window
+
+    Returns:
+        Tk: Tkinter window
+    """
     root = Tk()
     root.withdraw()
-    root.wm_attributes("-topmost", 1) # type: ignore
+    root.wm_attributes("-topmost", 1)  # type: ignore
+    return root
+
+
+def run_in_parallel(fns: list[Process]) -> None:
+    """
+    Run a list of functions in parallel
+
+    Args:
+        fns (list[Process]): List of functions to run in parallel
+    """
+    proc: list[Process] = []
+    for fn in fns:
+        fn.start()
+        proc.append(fn)
+    for p in proc:
+        p.join()
+
+
+def get_cc(save_stats: dict[str, Any]) -> str:
+    """Get the country code"""
+
+    if is_jp(save_stats):
+        return "jp"
+    return "en"
 
 
 def save_file(title: str, file_types: list[tuple[str, str]], path: str) -> str:
